Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(4848)

Unified Diff: cc/tiles/tile.cc

Issue 1202843008: cc: Fix BytesPerPixel issue and refactor. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: RowSize=>Width. Created 5 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: cc/tiles/tile.cc
diff --git a/cc/tiles/tile.cc b/cc/tiles/tile.cc
index 6052e5e0457e0f41cca41eab900166237f0bd6ee..640eec4566e5aa58d49b0959fc4b5461e1854307 100644
--- a/cc/tiles/tile.cc
+++ b/cc/tiles/tile.cc
@@ -69,10 +69,10 @@ void Tile::AsValueInto(base::trace_event::TracedValue* value) const {
size_t Tile::GPUMemoryUsageInBytes() const {
if (draw_info_.resource_) {
// We can use UncheckedSizeInBytes, since the tile size is determined by the
// compositor.
- return Resource::UncheckedMemorySizeBytes(draw_info_.resource_->size(),
- draw_info_.resource_->format());
+ return ResourceUtil::SizeInBytes(draw_info_.resource_->size(),
+ draw_info_.resource_->format());
}
return 0;
}
@@ -69,10 +69,10 @@ void Tile::AsValueInto(base::trace_event::TracedValue* value) const {
size_t Tile::GPUMemoryUsageInBytes() const {
if (draw_info_.resource_) {
- // We can use UncheckedSizeInBytes, since the tile size is determined by the
+ // We can use SizeInBytes, since the tile size is determined by the
// compositor.

Powered by Google App Engine
This is Rietveld 408576698